@@ -77,6 +77,7 @@ def main():
 )
 @click.option("--end", "-e", type=int, help="Dataload can be end")
 @click.option("--configfile", "-z", help="Use a Configfile instead of parameters")
+@click.option("--fields", "-k", help="Fields needed for output from the api result")
 def load(
     url,
     ionfile,
@@ -85,6 +86,7 @@ def load(
     inputfile,
     outputfile,
     configfile,
+    fields=None,
     start=None,
     end=None,
 ):
@@ -125,7 +127,7 @@ def load(
     dataframe = pd.read_excel(inputfile, dtype=str)
 
     return infor.main_load(
-        url, ionfile, program, method, dataframe, outputfile, start, end
+        url, ionfile, program, method, dataframe, outputfile, fields, start, end
     )
 
 
