@@ -111,7 +111,7 @@ def sendresults(url, _headers, data, timeout=65, stream=False):
                 elif z == max_attempt:
                     raise SystemExit(r)
 
-    except requests.exceptions.TooManyRedirects:
+    except requests.exceptions.TooManyRedirects as e:
         logger.error("Too many redirects")
         r = "Error - Too many redirects"
         raise SystemExit(e)
@@ -124,7 +124,7 @@ def sendresults(url, _headers, data, timeout=65, stream=False):
     return r
 
 
-def saveresults(r, df, program, index, chunk, MaxChunk=150, elements=1):
+def saveresults(r, df, program, index, chunk, MaxChunk=150, elements=1, fields =None):
 
     message = ""
     max_elements = elements
@@ -143,6 +143,7 @@ def saveresults(r, df, program, index, chunk, MaxChunk=150, elements=1):
                     for key in r["results"]:
 
                         methode = key["transaction"]
+                        records = key["records"]
 
                         if "errorMessage" in key:
                             error = key["errorMessage"]
@@ -152,7 +153,12 @@ def saveresults(r, df, program, index, chunk, MaxChunk=150, elements=1):
 
                         else:
                             message += methode + ":OK^_^"
-
+                            if(len(records) > 0 and fields is not None and len(fields) > 0):
+                                fields_list = fields.split("|")
+                                for field in fields_list:
+                                    for record in records:
+                                        df.loc[newindex, field] = record[field]
+                                        
                         df.loc[newindex, "MESSAGE"] = message
 
                         if elements == 1:
